# CLI

## lint

```eval_rst
.. autofunction:: deal._cli._lint.LintCommand
```

## stub

```eval_rst
.. autofunction:: deal._cli._stub.StubCommand
```

## test

```eval_rst
.. autofunction:: deal._cli._test.TestCommand
```

## memtest

```eval_rst
.. autofunction:: deal._cli._memtest.MemtestCommand
```

## prove

```eval_rst
.. autofunction:: deal._cli._prove.ProveCommand
```
